@@ -7,6 +7,10 @@ attributes(plantsfm[5:10,drop=TRUE])
 plantsfm[1:26 <11]
 attributes(plantsfm[1:26 <6])
 attributes(plantsfm[1:26 <6,drop=TRUE])
+plantsfm[names(plantsfm)[1:10] ]
+attributes(plantsfm[names(plantsfm)[1:10] ])
+attributes(plantsfm[names(plantsfm)[5:10],drop=TRUE])
+
 
 plantsfm[5] <- "m.4"
 plantsfm[1:5]
